Library ieee;
  use ieee.std_logic_1164.all;
--  use ieee.numeric_std.all;
  use ieee.std_logic_arith.all;
  use ieee.std_logic_unsigned.all;

entity T_DEBOUNCE is
end  T_DEBOUNCE;

architecture TEST of T_DEBOUNCE is

-------------------------------------------------------------------------------
--  Component Declarations
-------------------------------------------------------------------------------

component DEBOUNCE
  generic(
    CLK_RATE_MHZ              : natural := 100;
    MIN_SWITCHING_PERIOD_US   : natural := 1000);   
  port(
        clk                   : in    std_logic;
        areset                : in    std_logic; 
        bouncy_in             : in    std_logic;
        unbouncy_out          : out   std_logic      
  );
end component;


-------------------------------------------------------------------------------
--  Type Declarations
-------------------------------------------------------------------------------
  

-------------------------------------------------------------------------------
--  Constant Declarations
-------------------------------------------------------------------------------

  constant  PERIOD                   : time := 10 ns; -- 100 MHz
   
   
-------------------------------------------------------------------------------
--  Signal Declarations
-------------------------------------------------------------------------------
    
  -- input signals
  signal  t_clk                      : std_logic := '1';    
  signal  t_areset                   : std_logic := '1';  
  signal  t_bouncy_in                : std_logic := '0'; 
  
  
  -- inout signals
  
  -- output signals
  signal  t_unbouncy_out             : std_logic; 
  
    
  -- always have this
  signal  SIM_END                    : boolean := false;
  
  
-------------------------------------------------------------------------------
--  Procedure Declarations
-------------------------------------------------------------------------------


  
begin


-------------------------------------------------------------------------------
--  Component Instantiations
-------------------------------------------------------------------------------

  CONTROL1 : DEBOUNCE
  generic map(
    CLK_RATE_MHZ              => 100,
    MIN_SWITCHING_PERIOD_US   => 5) -- 5 us  
  port map(
        clk             => t_clk,
        areset          => t_areset, 
        bouncy_in       => t_bouncy_in,
        unbouncy_out    => t_unbouncy_out     
        );                

                              

-------------------------------------------------------------------------------
--  Concurrent Assignments
-------------------------------------------------------------------------------
  
  t_clk       <= not t_clk     after PERIOD/2  when SIM_END = false else '0';             
    
-------------------------------------------------------------------------------
--  Process Declarations
-------------------------------------------------------------------------------


  STIMULUS : process
  begin

    wait for 1 us;
    t_areset    <= '0';
    
    -- bouncy button going high
    wait for 6 us;
    t_bouncy_in <= '1';
      
    wait for 15 ns;
    t_bouncy_in <= '0';
      
    wait for 100 ns;
    t_bouncy_in <= '1';
           
    -- bouncy button going low
    wait for 10 us;
    t_bouncy_in <= '0';
      
    wait for 10 ns;
    t_bouncy_in <= '1';
      
    wait for 15 ns;
    t_bouncy_in <= '0';
      
    wait for 100 ns;
    t_bouncy_in <= '1';
      
    wait for 150 ns;
    t_bouncy_in <= '0';
      
    -- bouncy button going low
    wait for 10 us;
    t_bouncy_in <= '1';
      
    wait for 750 ns;
    t_bouncy_in <= '0';
      
    wait for 100 ns;
    t_bouncy_in <= '1';
    
    wait for 6 us;
                               
    SIM_END <= true;
    assert false report "Simulation complete" severity FAILURE;
  end process STIMULUS;
  

-------------------------------------------------------------------------------
--  Other Output Assignments
-------------------------------------------------------------------------------


end TEST;

configuration CFG_T_DEBOUNCE of T_DEBOUNCE is
for TEST
end for;
end CFG_T_DEBOUNCE;