-------------------------------------------------------------------------------
--  Copyright (c) 2017 Eclektek LLC. All rights reserved.
--
--
--  Developed by: William Carter
--
--  Permission is hereby granted, free of charge, to any person obtaining a copy of this software and  
--  associated documentation files (the "Software"), to deal with the Software without restriction,  
--  including without limitation the rights to use, copy, modify, merge, publish, sublicense and/or    
--  distribute copies of the Software, and to permit persons to whom the Software is furnished to do so,  
--  subject to the following conditions:
--
--      Redistributions of source code must retain the above copyright notice, this list of conditions 
--      and the following disclaimers.
--      Redistributions in binary form must reproduce the above copyright notice, this list of conditions 
--      and the following disclaimers in the documentation and/or other materials provided with the distribution.
--      Neither the names of William Carter, Eclektek LLC, nor the names of its 
--      contributors may be used to endorse or promote products derived from this Software without 
--      specific prior written permission from Eclektek LLC.
--      This Software is provided free of charge and Eclektek LLC reserves the right to sell copies of the 
--      Software in its original form. Anyone sub-licensing this Software will provide it free of charge.
--
--  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
--  LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
--  IN NO EVENT SHALL THE CONTRIBUTORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
--  WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
--  SOFTWARE OR THE USE OR OTHER DEALINGS WITH THE SOFTWARE.
-------------------------------------------------------------------------------
--  History :                                                                       
--                                                                                                                  
--  Date      By    Comments                                         
--  --------  ----  ------------------------------------------------------------
--  06/28/17  W.C.  Created                                     
--
-------------------------------------------------------------------------------
--  Project       : IO_EXPANDER                                                          
--  PCB           : Avnet Spartan 3A DSP Starter Kit
--  Device        : XCS3D1800A-FGG676 -4
--  Entity Name   : Spartan3ADSP1800
--  File Name     : Spartan3ADSP1800.vhd
--  Design Parent : none                                                          
--                                                                             
-------------------------------------------------------------------------------
--  Dependencies:
--
--  Spartan3ADSP1800_Test.vhd is uses the following components:
--    DEBOUNCE          DEBOUNCE.vhd
--    UART_DEBUGGER     UART_DEBUGGER.vhd
--
--  Spartan3ADSP1800_Test.vhd is uses the following packages:
--    Package        none
--
-------------------------------------------------------------------------------
--  Spartan3ADSP1800_Test.vhd
--    This entity is a "proof-of-concept" demonstrating that Ethernet PHYs can be used
--    be used to connect two different FPGA boards and allow each access to the other's
--    resources. Specifically, the purpose of this demonstration is to demonstrate one
--    way to increase the sparse IO capabilities of the Nexys Video board by allowing
--    the Nexys Video to access the Spartan 3A-DSP board's IO.
--
--    As this project is only meant to demonstrate "proof-of-concept" minimal functionality
--    is provided. The objective to to relect some inputs on the other board and to provide
--    a few pins that will allow measuring latency on an oscilloscope.
--
--    When the Spartan 3A-DSP board detects a change in the state of 8 user switches it sends a 
--    packet to the Nexys Video through the attached Ethernet cable. The 8-bit switch state are 
--    reflected on both Nexys Video LEDs and JA PMOD. When the Nexys Video detects a change in 
--    the 8 user switches or JB pins [10:7] it sends a packet to the 3A-DSP board where the 
--    switches are relected in the LEDs and the JB pins are reflected on J7.
--
--    Both boards have a similar design. There are separate clock domains for sampling inputs
--    and sending packets and for receiving packets and updating outputs. A counter creates a 
--    1 us sample period for detecting input changes and possibly generating Tx packets. The
--    Ethernet receiver is available to update outputs at any time.  
--
--    The DP83865DVH Ethernet PHY is a 10/100/1000 device operating in the GMII interface mode
--    at 1000 Mbps.
--
--    The data packets sent by both boards consists of 5 bytes: 2-byte preamble, 2 byte payload,
--    and one byte terminator. The board receiving packets will not update outputs unless the
--    packet is validated by having the correct preamble and terminator bytes. No error other
--    checking is performed.
--
-------------------------------------------------------------------------------
--  Limitations
------------------------------------------------------------------------------
--  ToDo
--
-------------------------------------------------------------------------------
--  NOTES:
--
-------------------------------------------------------------------------------



Library ieee;
  use ieee.std_logic_1164.all;
  use ieee.std_logic_arith.all;
  use ieee.std_logic_unsigned.all;
  use ieee.math_real.all;
  
entity Spartan3ADSP1800 is
  port(
       sys_clk          : in    std_logic;                      -- 125 MHz
       sys_rst_n        : in    std_logic;                      -- TPS3307 Power-on reset
       led              : out   std_logic_vector(7 downto 0);
       
       -- user buttons
       buttons          : in    std_logic_vector(3 downto 0);   -- '1' when pressed
       
       -- user switches 
       dip_switches     : in    std_logic_vector(7 downto 0);
       
       -- Ethernet Interface
       eth_rst_n        : out   std_logic;
       eth_tx_clk       : in    std_logic;
       eth_gtx_clk      : out   std_logic;
       eth_tx_en        : out   std_logic;
       eth_txer         : out   std_logic;
       eth_tx_data      : out   std_logic_vector(7 downto 0);
       eth_rx_clk       : in    std_logic;
       eth_crs          : in    std_logic;
       eth_col          : in    std_logic;
       eth_rx_dv        : in    std_logic;
       eth_rx_er        : in    std_logic;
       eth_rx_data      : in    std_logic_vector(7 downto 0);
       eth_mii_clk      : out   std_logic;
       eth_mii_data     : inout std_logic;
       
       -- DCE RS-232 connector
       rs232_rx         : in    std_logic;
       rs232_tx         : out   std_logic;
              
       -- PMOD J6
       j6_pin1          : out   std_logic;
       j6_pin3          : out   std_logic;
       
       -- PMOD J7
       j7_pin1          : out   std_logic;
       j7_pin2          : out   std_logic;
       j7_pin3          : out   std_logic;
       j7_pin4          : out   std_logic;
       
       -- J8 System Ace Header
       sam_a            : in    std_logic_vector(6 downto 0);
       sam_d            : in    std_logic_vector(15 downto 0);
       sam_clk          : in    std_logic;
       sam_cen          : in    std_logic;
       sam_oen          : in    std_logic;
       sam_wen          : in    std_logic;        
       sam_rst          : in    std_logic
  );
end entity;

architecture rtl of Spartan3ADSP1800 is

-------------------------------------------------------------------------------
--  Component Declarations
-------------------------------------------------------------------------------

component DEBOUNCE
  generic(
    CLK_RATE_MHZ              : natural := 100;
    MIN_SWITCHING_PERIOD_US   : natural := 1000);   
  port(
        clk                   : in    std_logic;
        areset                : in    std_logic; 
        bouncy_in             : in    std_logic;
        unbouncy_out          : out   std_logic      
  );
end component;

component DCM0
   port ( CLKIN_IN        : in    std_logic; 
          RST_IN          : in    std_logic; 
          CLKIN_IBUFG_OUT : out   std_logic; 
          CLK0_OUT        : out   std_logic; 
          CLK90_OUT       : out   std_logic; 
          LOCKED_OUT      : out   std_logic);
end component;


component UART_DEBUGGER
  generic(
    CLK_RATE        : natural := 100000000;
    BAUD_RATE       : natural := 921600;
    DATA_CHARS      : natural := 8);   -- 32-bit register width = 8*DATA_CHARS);
  port(
        -- GLOBAL SIGNALS
        clk                 : in    std_logic; -- global clock
        areset              : in    std_logic; -- global reset
        
        -- interface
        data_write_stb      : in    std_logic;
        data_in             : in    std_logic_vector(4*DATA_CHARS-1 downto 0);
        busy                : out   std_logic;
        
        -- UART signals
        txd_out             : out   std_logic
  );
end component;

-------------------------------------------------------------------------------
--  Type Declarations
-------------------------------------------------------------------------------

type etx_sm_states is (t_idle, t_sample, t_load, t_send);
type erx_sm_states is (r_idle, r_div, r_checkv, r_wrdata);

-------------------------------------------------------------------------------
--  Constant Declarations
-------------------------------------------------------------------------------


  -- interface packet definition
  -- <preamble (2) ><payload (2) ><terminator (1) >
  -- NV payload bytes: <3A_LEDS><3A_J18_IO>
  -- 3A payload bytes: <NV_LEDS><NV_JA>
  constant PREAMBLE_SYMBOLS         : std_logic_vector(15 downto 0) := X"555D";
  constant TERMINATOR_SYMBOL        : std_logic_vector(7 downto 0) := X"AA";
  constant NUM_PREAMBLE_BYTES       : natural := 2;  
  constant NUM_PAYLOAD_BYTES        : natural := 2;  
  constant NUM_TERMINATOR_BYTES     : natural := 1;
  constant NUM_PACKET_BYTES         : natural := NUM_PREAMBLE_BYTES + NUM_PAYLOAD_BYTES + NUM_TERMINATOR_BYTES;
  constant SHIFT_REGISTER_WIDTH     : natural := 8*NUM_PACKET_BYTES;    
  constant UPDATE_RATE_KHZ          : natural := 10000; -- 100 ns input sample period 
  constant TX_CLOCK_RATE_KHZ        : natural := 125000;
  constant SAMPLE_STROBE_COUNT      : natural := integer(round(real(TX_CLOCK_RATE_KHZ)/real(UPDATE_RATE_KHZ)));
  constant PERIOD_COUNTER_WIDTH     : natural := integer(ceil(log2(real(SAMPLE_STROBE_COUNT))));


-------------------------------------------------------------------------------
--  Signal Declarations
-------------------------------------------------------------------------------

signal  current_tstate        : etx_sm_states;
signal  current_rstate        : erx_sm_states;

signal  clk125          : std_logic;
signal  clk125p90       : std_logic;
signal  pll_locked      : std_logic;
signal  areset          : std_logic;
signal  eth_tx_sr       : std_logic_vector(SHIFT_REGISTER_WIDTH-1 downto 0);
signal  eth_rx_sr       : std_logic_vector(SHIFT_REGISTER_WIDTH-1 downto 0);
signal  btn_lo_cnt      : std_logic_vector(25 downto 0);
signal  send_data_stb   : std_logic;
signal  send_data       : std_logic;
signal  byte_count      : std_logic_vector(5 downto 0);
signal  irxd            : std_logic_vector(7 downto 0);
signal  irxdiv          : std_logic;
signal  irxdiv_r        : std_logic;
signal  irxdiv_stb      : std_logic;
signal  itxd            : std_logic;
signal  input_event     : std_logic;
signal  debounced_sw    : std_logic_vector(7 downto 0);
signal  sw_reg          : std_logic_vector(7 downto 0);
signal  j20_reg         : std_logic_vector(3 downto 0) := (others => '0');
signal  j7_reg          : std_logic_vector(3 downto 0) := (others => '0');
signal  led_reg         : std_logic_vector(7 downto 0); 
signal  eth_tx_payload  : std_logic_vector(8*NUM_PAYLOAD_BYTES-1 downto 0); 
signal  eth_rx_preamble : std_logic_vector(8*NUM_PREAMBLE_BYTES-1 downto 0);
signal  eth_rx_payload  : std_logic_vector(8*NUM_PAYLOAD_BYTES-1 downto 0);
signal  eth_rx_term     : std_logic_vector(8*NUM_TERMINATOR_BYTES-1 downto 0);
signal  valid_rx_packet : std_logic;
signal  period_count    : std_logic_vector(PERIOD_COUNTER_WIDTH-1 downto 0);
signal  dbg_uart_tx     : std_logic;

signal  debug_wren      : std_logic;
signal  debug_busy      : std_logic;


-------------------------------------------------------------------------------
--  Procedure Declarations
-------------------------------------------------------------------------------
  
  
begin


-------------------------------------------------------------------------------
--  Component Instantiations
-------------------------------------------------------------------------------

  DCM_inst : DCM0
     port map( 
       CLKIN_IN        => sys_clk, -- 125 MHz
       RST_IN          => '0',
       CLKIN_IBUFG_OUT => open,
       CLK0_OUT        => clk125,
       CLK90_OUT       => clk125p90,
       LOCKED_OUT      => pll_locked
       );                 

  GEN_debounce : for i in 7 downto 0 generate
    DEBOUNCE_inst : DEBOUNCE
    generic map(
      CLK_RATE_MHZ              => 125,
      MIN_SWITCHING_PERIOD_US   => 2000) -- 2 milliseconds  
    port map(
          clk             => clk125,
          areset          => areset, 
          bouncy_in       => dip_switches(i),
          unbouncy_out    => debounced_sw(i)     
          );                 
  end generate;
 
  DBG0 : UART_DEBUGGER
  generic map(
    CLK_RATE    => 125000000,
    BAUD_RATE   => 921600,  -- 921600
    DATA_CHARS  => 2*NUM_PACKET_BYTES)   -- 16-bit register width = 4*DATA_CHARS);
  port map(
        clk             => eth_rx_clk,
        areset          => areset,
        data_write_stb  => debug_wren,
        data_in         => eth_rx_sr,
        busy            => debug_busy,
        txd_out         => dbg_uart_tx);  
  
-------------------------------------------------------------------------------
--  Concurrent Assignments
-------------------------------------------------------------------------------

  areset  <= (not sys_rst_n) or buttons(0);
  irxd    <= eth_rx_data;
  irxdiv  <= eth_rx_dv;
  
  
  input_event     <= '0' when sw_reg = debounced_sw else '1';
  send_data_stb   <= '1' when current_tstate = t_load else '0';
  valid_rx_packet <= '1' when (eth_rx_preamble = PREAMBLE_SYMBOLS) and (eth_rx_term = TERMINATOR_SYMBOL) else '0';
  
  -- send SW to NV LEDs
  eth_tx_payload  <= debounced_sw & X"24"; -- added dummy 0x24 during debugging
  
  eth_rx_preamble <= eth_rx_sr(eth_rx_sr'left downto eth_rx_sr'left-(8*NUM_PREAMBLE_BYTES-1));        -- [39:24]
  eth_rx_payload  <= eth_rx_sr(eth_rx_sr'left-(8*NUM_PREAMBLE_BYTES) downto 8*NUM_TERMINATOR_BYTES);  -- [23:8]
  eth_rx_term     <= eth_rx_sr(8*NUM_TERMINATOR_BYTES-1 downto 0);                                    -- [7:0]
  
            
  
  send_data       <= '1' when byte_count > "000000" else
                     '1' when current_tstate = t_load else
                     '0'; 
                     
  irxdiv_stb  <= '1' when current_rstate = r_checkv else '0';

  debug_wren  <= '1' when irxdiv_stb = '1' and debug_busy = '0' else '0';
  
    
-------------------------------------------------------------------------------
--  Process Declarations
-------------------------------------------------------------------------------


  -- the sample period counter
  process(clk125, areset)
  begin
    if areset = '1' then
      period_count  <= (others => '0');
    elsif falling_edge(clk125) then
      if period_count < SAMPLE_STROBE_COUNT then
        period_count  <= period_count + 1;
      else   
        period_count  <= (others => '0');
      end if;
    end if;  
  end process;

  -- track Tx bytes ( nibbles for the 3A )
  process(clk125, areset)
  begin
    if areset = '1' then
      byte_count  <= (others => '0');
    elsif falling_edge(clk125) then
      if send_data_stb = '1' then
        byte_count  <= conv_std_logic_vector(NUM_PACKET_BYTES,6); 
      elsif byte_count > "000000" then
        byte_count  <= byte_count - 1;
      end if;
    end if;  
  end process;
  
  -- Ethernet TX data shift register
  process(clk125, areset)
  begin
    if areset = '1' then
      eth_tx_sr  <= PREAMBLE_SYMBOLS & eth_tx_payload & TERMINATOR_SYMBOL;
    elsif falling_edge(clk125) then
      if send_data_stb = '1' then
        eth_tx_sr  <= PREAMBLE_SYMBOLS & eth_tx_payload & TERMINATOR_SYMBOL;
      elsif send_data = '1' then   
        eth_tx_sr  <= eth_tx_sr(eth_tx_sr'left -8 downto 0) & X"00";
      end if;
    end if;  
  end process;
  
  -- Ethernet RX data shift register
  process(eth_rx_clk, areset)
  begin
    if areset = '1' then
      eth_rx_sr  <= (others => '0');
    elsif rising_edge(eth_rx_clk) then
      if current_rstate = r_idle then
        eth_rx_sr  <= (others => '0');
      elsif irxdiv = '1' then   
        eth_rx_sr  <= eth_rx_sr(eth_rx_sr'left -8 downto 0) & irxd;
      end if;
    end if;  
  end process;

  -- a state machine to control the Ethernet transmitter
-- type etx_sm_states is (t_idle, t_sample, t_load, t_send);
  ETX_SM : process (clk125, areset)
  begin
    if (areset = '1') then
      sw_reg          <= (others => '0');
      j20_reg         <= (others => '0');
      current_tstate  <= t_idle;
    elsif falling_edge(clk125) then
      case current_tstate is
        -- wait until period counter matches sample count
        when t_idle =>
          if period_count = SAMPLE_STROBE_COUNT then  
            current_tstate   <= t_sample;
          else
            current_tstate  <= t_idle;
          end if;
          
        -- check for changes          
        when t_sample =>
          sw_reg   <= debounced_sw;
          j20_reg  <= X"0";
          if input_event = '1' then
            current_tstate  <= t_load;
          else   
            current_tstate  <= t_idle;           
          end if;  
         
        -- send a packet if anything has changed          
        when t_load =>
          current_tstate  <= t_send;
                   
        when t_send =>
          current_tstate  <= t_idle;
          
        when others =>
          current_tstate  <= t_idle;
        
      end case;
    end if;      
  end process ETX_SM; 



  -- a state machine to control the Ethernet transmitter
-- type erx_sm_states is (r_idle, r_div, r_checkv, r_wrdata);
  ERX_SM : process (eth_rx_clk, areset)
  begin
    if (areset = '1') then
      j7_reg    <= (others => '0');
      led_reg   <= (others => '0');  
      current_rstate  <= r_idle;
    elsif rising_edge(eth_rx_clk) then
      case current_rstate is                                
        when r_idle =>                                      
          if irxdiv = '1' then  
            current_rstate   <= r_div;
          else
            current_rstate  <= r_idle;
          end if;
            
        -- wait until all eth_rx data is in       
        when r_div =>
          if irxdiv = '0' then
            current_rstate  <= r_checkv;
          else   
            current_rstate  <= r_div;           
          end if;  
                 
        -- check that the preamble and termination bytes are correct  
        when r_checkv =>
          if valid_rx_packet = '1' then
            current_rstate  <= r_wrdata;
          else   
            current_rstate  <= r_idle;           
          end if;  
             
        -- only write if the packet is valid      
        when r_wrdata =>
          led_reg   <= eth_rx_payload(15 downto 8); -- need to use constants 
          j7_reg    <= eth_rx_payload(3 downto 0); -- need to use constants
          current_rstate  <= r_idle;
          
        when others =>
          current_rstate  <= r_idle;
        
      end case;
    end if;      
  end process ERX_SM; 

-------------------------------------------------------------------------------
--  Other Output Assignments
-------------------------------------------------------------------------------
  
  -- loopback perhaps
  eth_tx_data   <= eth_tx_sr(eth_tx_sr'left downto eth_tx_sr'left -7);
  eth_tx_en     <= send_data;
  eth_txer      <= '0';
  eth_gtx_clk   <= clk125p90;  
  
  eth_mii_clk   <= '1';
  eth_mii_data  <= 'Z';
  eth_rst_n     <= not areset;
  
  led           <= led_reg;
  
  rs232_tx      <= 'Z';
  j6_pin1       <= dbg_uart_tx;
  j6_pin3       <= '0'when current_rstate = r_idle else '1';
  
  j7_pin1       <= j7_reg(0);
  j7_pin2       <= j7_reg(1);
  j7_pin3       <= j7_reg(2);
  j7_pin4       <= j7_reg(3);
  
  
end rtl;
